===
API
===

Here lists all documented classes and functions. Not all members are documented yet. Some members, such as the backported modules, are not documented here.

If the documentation is not sufficient, please take a look at the source code. Suggestions and improvements are welcomed.

.. Warning:: The API is not thread-safe. It is intended to be run asynchronously with Trollius.

.. Note:: Many functions also are decorated with the :func:`trollius.coroutine` decorator. For more information, see http://trollius.readthedocs.org/.


wpull Package
=============

.. toctree::

    api/_luahook
    api/abstract
    api/abstract.client
    api/abstract.request
    api/abstract.stream
    api/app
    api/bandwidth
    api/body
    api/builder
    api/cache
    api/collections
    api/connection
    api/converter
    api/cookie
    api/database
    api/database.base
    api/database.sqlmodel
    api/database.sqltable
    api/database.wrap
    api/debug
    api/decompression
    api/dns
    api/document
    api/document.base
    api/document.css
    api/document.html
    api/document.htmlparse
    api/document.htmlparse.base
    api/document.htmlparse.element
    api/document.htmlparse.html5lib_
    api/document.htmlparse.lxml_
    api/document.javascript
    api/document.sitemap
    api/document.util
    api/document.xml
    api/engine
    api/errors
    api/factory
    api/ftp
    api/ftp.client
    api/ftp.command
    api/ftp.ls
    api/ftp.ls.date
    api/ftp.ls.listing
    api/ftp.ls.parse
    api/ftp.request
    api/ftp.stream
    api/ftp.util
    api/hook
    api/http
    api/http.chunked
    api/http.client
    api/http.proxy
    api/http.redirect
    api/http.request
    api/http.robots
    api/http.stream
    api/http.util
    api/http.web
    api/item
    api/namevalue
    api/observer
    api/options
    api/phantomjs
    api/processor
    api/processor.base
    api/processor.delegate
    api/processor.ftp
    api/processor.phantomjs
    api/processor.rule
    api/processor.web
    api/proxy
    api/recorder
    api/recorder.base
    api/recorder.demux
    api/recorder.document
    api/recorder.printing
    api/recorder.progress
    api/recorder.warc
    api/regexstream
    api/robotstxt
    api/scraper
    api/scraper.base
    api/scraper.css
    api/scraper.html
    api/scraper.javascript
    api/scraper.sitemap
    api/scraper.util
    api/stats
    api/string
    api/url
    api/urlfilter
    api/util
    api/version
    api/waiter
    api/warc
    api/wrapper
    api/writer

